<?php

require_once 'Wp/Admin.php';
require_once 'Wp/Hook.php';

class Anomify_Wp
{

	const PLUGIN_DIR = 'anomify';

	public static function init ()
	{

		if ((true == function_exists('is_admin')) && (true == is_admin())) {
			// Admin settings go here
			add_action('admin_menu', array('Anomify_Wp_Admin', 'addOptionsPage'));
		}

		if (false == Anomify_Config::getInstance()->getEnabled()) {
			return;
		}

		// Log unhandled exceptions
		set_exception_handler(array('Anomify_Wp_Hook', 'exception_handler'));

		add_action('shutdown', array('Anomify', 'export'), null, 0);

		self::_addHookAction('anomify_increment_plugin_metric', null, 2);

		// https://developer.wordpress.org/reference/hooks/wp/
		self::_addHookAction('wp', null, 1);

		// https://developer.wordpress.org/reference/hooks/post_updated/
		self::_addHookAction('post_updated', null, 2);

		// https://developer.wordpress.org/reference/hooks/deleted_post/
		self::_addHookAction('deleted_post', null, 2);

		// https://developer.wordpress.org/reference/hooks/comment_post/
		self::_addHookAction('comment_post', null, 3);

		// https://developer.wordpress.org/reference/hooks/transition_post_status/
		self::_addHookAction('transition_post_status', null, 3);

		// https://developer.wordpress.org/reference/hooks/field_no_prefix_save_pre/
		self::_addHookAction('content_save_pre', 10, 1);

		if (true == Anomify_Config::getInstance()->get3pPluginIntegrationEnabled('wp-statistics')) {

			/*
			* WP Statistics plugin integration hooks
			*/

			// WP Statistics New Visitor
			self::_addHookFilter('wp_statistics_visitor_information', null, 1);

			// WP Statistics Returning Visitor
			self::_addHookAction('wp_statistics_update_visitor_hits', null, 2);

			// WP Statistics Exclusion
			self::_addHookAction('wp_statistics_save_exclusion', null, 2);

		}

	}

	private static function _addHookAction ($sHook, $iPriority=null, $iArgs=null)
	{
		add_action($sHook, array('Anomify_Wp_Hook', $sHook), $iPriority, $iArgs);
	}

	private static function _addHookFilter ($sHook, $iPriority=null, $iArgs=null)
	{
		add_filter($sHook, array('Anomify_Wp_Hook', $sHook), $iPriority, $iArgs);
	}

	public static function uninstall ()
	{
		delete_option(Anomify_Config::OPTION_DB_KEY);
	}

}
